@@ -17,13 +17,9 @@ import os
 import warnings
 
 import appdirs
+from keystoneauth1 import loading
 import yaml
 
-try:
-    import keystoneclient.auth as ksc_auth
-except ImportError:
-    ksc_auth = None
-
 from os_client_config import cloud_config
 from os_client_config import defaults
 from os_client_config import exceptions
@@ -283,15 +279,38 @@ class OpenStackConfig(object):
         cloud = self._fix_backwards_project(cloud)
         cloud = self._fix_backwards_auth_plugin(cloud)
         cloud = self._fix_backwards_interface(cloud)
+        cloud = self._handle_domain_id(cloud)
+        return cloud
+
+    def _handle_domain_id(self, cloud):
+        # Allow people to just specify domain once if it's the same
+        mappings = {
+            'domain_id': ('user_domain_id', 'project_domain_id'),
+            'domain_name': ('user_domain_name', 'project_domain_name'),
+        }
+        for target_key, possible_values in mappings.items():
+            for key in possible_values:
+                if target_key in cloud['auth'] and key not in cloud['auth']:
+                    cloud['auth'][key] = cloud['auth'][target_key]
+            cloud['auth'].pop(target_key, None)
         return cloud
 
     def _fix_backwards_project(self, cloud):
         # Do the lists backwards so that project_name is the ultimate winner
+        # Also handle moving domain names into auth so that domain mapping
+        # is easier
         mappings = {
             'project_id': ('tenant_id', 'tenant-id',
                            'project_id', 'project-id'),
             'project_name': ('tenant_name', 'tenant-name',
                              'project_name', 'project-name'),
+            'domain_id': ('domain_id', 'domain-id'),
+            'domain_name': ('domain_name', 'domain-name'),
+            'user_domain_id': ('user_domain_id', 'user-domain-id'),
+            'user_domain_name': ('user_domain_name', 'user-domain-name'),
+            'project_domain_id': ('project_domain_id', 'project-domain-id'),
+            'project_domain_name': (
+                'project_domain_name', 'project-domain-name'),
         }
         for target_key, possible_values in mappings.items():
             target = None
@@ -376,19 +395,27 @@ class OpenStackConfig(object):
         if opt_name in config:
             return config[opt_name]
         else:
-            for d_opt in opt.deprecated_opts:
+            for d_opt in opt.deprecated:
                 d_opt_name = d_opt.name.replace('-', '_')
                 if d_opt_name in config:
                     return config[d_opt_name]
 
-    def _validate_auth(self, config):
-        # May throw a keystoneclient.exceptions.NoMatchingPlugin
-        if config['auth_type'] == 'admin_endpoint':
-            auth_plugin = ksc_auth.token_endpoint.Token
-        else:
-            auth_plugin = ksc_auth.get_plugin_class(config['auth_type'])
+    def _get_auth_loader(self, config):
+        # Re-use the admin_token plugin for the "None" plugin
+        # since it does not look up endpoints or tokens but rather
+        # does a passthrough. This is useful for things like Ironic
+        # that have a keystoneless operational mode, but means we're
+        # still dealing with a keystoneauth Session object, so all the
+        # _other_ things (SSL arg handling, timeout) all work consistently
+        if config['auth_type'] in (None, "None", ''):
+            config['auth_type'] = 'admin_token'
+            config['auth']['token'] = None
+        return loading.get_plugin_loader(config['auth_type'])
 
-        plugin_options = auth_plugin.get_options()
+    def _validate_auth(self, config, loader):
+        # May throw a keystoneauth1.exceptions.NoMatchingPlugin
+
+        plugin_options = loader.get_options()
 
         for p_opt in plugin_options:
             # if it's in config.auth, win, kill it from config dict
@@ -400,19 +427,8 @@ class OpenStackConfig(object):
             if not winning_value:
                 winning_value = self._find_winning_auth_value(p_opt, config)
 
-            # if the plugin tells us that this value is required
-            # then error if it's doesn't exist now
-            if not winning_value and p_opt.required:
-                raise exceptions.OpenStackConfigException(
-                    'Unable to find auth information for cloud'
-                    ' {cloud} in config files {files}'
-                    ' or environment variables. Missing value {auth_key}'
-                    ' required for auth plugin {plugin}'.format(
-                        cloud=cloud, files=','.join(self._config_files),
-                        auth_key=p_opt.name, plugin=config.get('auth_type')))
-
             # Clean up after ourselves
-            for opt in [p_opt.name] + [o.name for o in p_opt.deprecated_opts]:
+            for opt in [p_opt.name] + [o.name for o in p_opt.deprecated]:
                 opt = opt.replace('-', '_')
                 config.pop(opt, None)
                 config['auth'].pop(opt, None)
@@ -435,13 +451,16 @@ class OpenStackConfig(object):
         :param string cloud:
             The name of the configuration to load from clouds.yaml
         :param boolean validate:
-            Validate that required arguments are present and certain
-            argument combinations are valid
+            Validate the config. Setting this to False causes no auth plugin
+            to be created. It's really only useful for testing.
         :param Namespace argparse:
             An argparse Namespace object; allows direct passing in of
             argparse options to be added to the cloud config.  Values
             of None and '' will be removed.
         :param kwargs: Additional configuration options
+
+        :raises: keystoneauth1.exceptions.MissingRequiredOptions
+            on missing required auth parameters
         """
 
         if cloud is None and self.envvar_key in self.get_cloud_names():
@@ -471,12 +490,12 @@ class OpenStackConfig(object):
                 if type(config[key]) is not bool:
                     config[key] = get_boolean(config[key])
 
-        if 'auth_type' in config:
-            if config['auth_type'] in ('', 'None', None):
-                validate = False
-
-        if validate and ksc_auth:
-            config = self._validate_auth(config)
+        loader = self._get_auth_loader(config)
+        if validate:
+            config = self._validate_auth(config, loader)
+            auth_plugin = loader.load_from_options(**config['auth'])
+        else:
+            auth_plugin = None
 
         # If any of the defaults reference other values, we need to expand
         for (key, value) in config.items():
@@ -492,7 +511,8 @@ class OpenStackConfig(object):
         return cloud_config.CloudConfig(
             name=cloud_name, region=config['region_name'],
             config=self._normalize_keys(config),
-            prefer_ipv6=prefer_ipv6)
+            prefer_ipv6=prefer_ipv6,
+            auth_plugin=auth_plugin)
 
     @staticmethod
     def set_one_cloud(config_file, cloud, set_config=None):
